@@ -1,6 +1,6 @@
 #######################################################################
 # stream -  Infrastructure for Data Stream Mining
-# Copyright (C) 2013 Michael Hahsler, Matthew Bolanos, John Forrest 
+# Copyright (C) 2013 Michael Hahsler, Matthew Bolanos, John Forrest
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,23 +18,25 @@
 
 DSD_MOA <- function(...) stop("DSD_MOA is an abstract class and cannot be instantiated!")
 
-get_points.DSD_MOA <- function(x, n=1, 
+get_points.DSD_MOA <- function(x, n=1,
   outofpoints=c("stop", "warn", "ignore"),
   cluster=FALSE, class=FALSE, ...) {
-	
+
   ### MOA streams cannot be out of points.
-  
+
 	if (n < 1) stop("n must be > 0")
-	
+
 	# pre-allocating the space for the matrix
 	data <- matrix(NA, nrow=n, ncol=x$d)
-	
+
 	a <- integer(n)
 
 	# unpackaging the java instances
 	for (i in 1:n) {
-		instance <- .jcall(x$javaObj, "Lweka/core/Instance;", "nextInstance")
-		row <- .jcall(instance, "[D", "toDoubleArray")
+
+	  instance <- .jcall(x$javaObj, "Lmoa/core/InstanceExample;", "nextInstance")
+	  instance <- .jcall(instance, "Lcom/yahoo/labs/samoa/instances/Instance;", "getData")
+	  row <- .jcall(instance, "[D", "toDoubleArray")
 		cl <- .jcall(instance, "D", "classValue")
 		data[i,] <- row[1:x$d]
 		a[i] <- cl
@@ -44,10 +46,10 @@ get_points.DSD_MOA <- function(x, n=1,
     a <- as.integer(a)
     a[a==x$k] <- NA_integer_
     a <- a + 1L
-	
+
   if(cluster) attr(data, "cluster") <- a
   if(class) data <- cbind(data, class = a)
-	
+
 	data
 }
 
