@@ -9,13 +9,13 @@ options(width = 75, digits = 3, prompt = 'R> ')
 ###################################################
 ### code chunk number 2: streamMOA.Rnw:31-32
 ###################################################
-set.seed(1234) 
+set.seed(1234)
 
 
 ###################################################
 ### code chunk number 3: data_bng
 ###################################################
-library("stream") 
+library("stream")
 stream <- DSD_Memory(DSD_BarsAndGaussians(noise=0.05), n=5500)
 stream
 plot(stream)
@@ -24,7 +24,7 @@ plot(stream)
 ###################################################
 ### code chunk number 4: streamMOA.Rnw:57-61
 ###################################################
-sample <- DSC_TwoStage(micro=DSC_Sample(k=100), macro=DSC_Kmeans(k=4)) 
+sample <- DSC_TwoStage(micro=DSC_Sample(k=100), macro=DSC_Kmeans(k=4))
 window <- DSC_TwoStage(micro=DSC_Window(horizon=100), macro=DSC_Kmeans(k=4))
 dstream <- DSC_DStream(gridsize=.7)
 dbstream <- DSC_DBSTREAM(r=.45)
@@ -34,17 +34,17 @@ dbstream <- DSC_DBSTREAM(r=.45)
 ### code chunk number 5: streamMOA.Rnw:66-69
 ###################################################
 library("streamMOA")
-denstream <- DSC_DenStream(epsilon=.5, mu=1) 
-clustream <- DSC_CluStream(m=100, k=4) 
+denstream <- DSC_DenStream_MOA(epsilon=.5, mu=1)
+clustream <- DSC_CluStream_MOA(m=100, k=4)
 
 
 ###################################################
 ### code chunk number 6: streamMOA.Rnw:76-82
 ###################################################
-algorithms <- list(Sample=sample, Window=window, 'D-Stream'=dstream, 
-  DBSTREAM=dbstream, DenStream=denstream, CluStream=clustream)
+algorithms <- list(Sample=sample, Window=window, 'D-Stream'=dstream,
+  DBSTREAM=dbstream, DenStream_MOA=denstream, CluStream_MOA=clustream)
 for(a in algorithms) {
-  reset_stream(stream) 
+  reset_stream(stream)
   update(a, stream, 5000)
 }
 
@@ -61,7 +61,7 @@ sapply(algorithms, nclusters, type="micro")
 op <- par(no.readonly = TRUE)
 layout(mat=matrix(1:6, ncol=2))
 for(a in algorithms) {
-  reset_stream(stream) 
+  reset_stream(stream)
   plot(a, stream, main=description(a), type="micro")
 }
 par(op)
@@ -73,7 +73,7 @@ par(op)
 op <- par(no.readonly = TRUE)
 layout(mat=matrix(1:6, ncol=2))
 for(a in algorithms) {
-  reset_stream(stream) 
+  reset_stream(stream)
   plot(a, stream, main=description(a), assignment=TRUE, weight=FALSE, type="micro")
 }
 par(op)
@@ -83,10 +83,10 @@ par(op)
 ### code chunk number 10: streamMOA.Rnw:169-175
 ###################################################
 sapply(algorithms, FUN=function(a) {
-  reset_stream(stream, 1001) 
-  evaluate(a, stream, 
-    measure=c("numMicroClusters", "purity", "SSQ", "silhouette"), 
-    n=500, assignmentMethod="auto", type="micro")
+  reset_stream(stream, 1001)
+  evaluate(a, stream,
+    measure=c("numMicroClusters", "purity", "SSQ", "silhouette"),
+    n=500, assignmentMethod = "auto", type = "micro")
 })
 
 
@@ -96,7 +96,7 @@ sapply(algorithms, FUN=function(a) {
 op <- par(no.readonly = TRUE)
 layout(mat=matrix(1:6, ncol=2))
 for(a in algorithms) {
-  reset_stream(stream) 
+  reset_stream(stream)
   plot(a, stream, main=description(a), type="both")
 }
 par(op)
@@ -106,9 +106,9 @@ par(op)
 ### code chunk number 12: streamMOA.Rnw:223-228
 ###################################################
 sapply(algorithms, FUN=function(a) {
-  reset_stream(stream, 1001) 
-  evaluate(a, stream, measure=c("numMacroClusters","purity", "SSQ", "cRand"), 
-    n=500, assign="micro", type="macro")
+  reset_stream(stream, 1001)
+  evaluate(a, stream, measure = c("numMacroClusters","purity", "SSQ", "cRand"),
+    n = 500, assign = "micro", type = "macro")
 })
 
 
@@ -122,9 +122,9 @@ stream <- DSD_Memory(DSD_Benchmark(1), 5000)
 ###################################################
 ### code chunk number 14: moa1
 ###################################################
-plot(stream, 250, xlim=c(0,1), ylim=c(0,1))
-arrows(.15,.85,.85,.15, col=rgb(.8,.8,.8,.6), lwd=10)
-arrows(.15,.15,.85,.85, col=rgb(.8,.8,.8,.6), lwd=10)
+plot(stream, 250, xlim = c(0,1), ylim = c(0,1))
+arrows(.15,.85,.85,.15, col = rgb(.8,.8,.8,.6), lwd = 10)
+arrows(.15,.15,.85,.85, col = rgb(.8,.8,.8,.6), lwd = 10)
 reset_stream(stream)
 
 
@@ -132,15 +132,15 @@ reset_stream(stream)
 ### code chunk number 15: streamMOA.Rnw:273-284
 ###################################################
 algorithms <- list(
-  'Sample' = DSC_TwoStage(micro=DSC_Sample(k=100, biased=TRUE), 
-    macro=DSC_Kmeans(k=2)), 
-  'Window' = DSC_TwoStage(micro=DSC_Window(horizon=100, lambda=.01), 
+  'Sample' = DSC_TwoStage(micro=DSC_Sample(k=100, biased=TRUE),
     macro=DSC_Kmeans(k=2)),
-  
+  'Window' = DSC_TwoStage(micro=DSC_Window(horizon=100, lambda=.01),
+    macro=DSC_Kmeans(k=2)),
+
   'D-Stream' = DSC_DStream(gridsize=.1, lambda=.01),
   'DBSTREAM' = DSC_DBSTREAM(r=.05, lambda=.01),
-  'DenStream' = DSC_DenStream(epsilon=.1, lambda=.01),
-  'CluStream' = DSC_CluStream(m=100, k=2) 
+  'DenStream' = DSC_DenStream_MOA(epsilon=.1, lambda=.01),
+  'CluStream' = DSC_CluStream_MOA(m=100, k=2)
 )
 
 
@@ -153,9 +153,9 @@ reset_stream(stream)
 
 evaluation <- lapply(algorithms, FUN=function(a) {
   reset_stream(stream)
-  evaluate_cluster(a, stream, 
+  evaluate_cluster(a, stream,
     type="macro", assign="micro",
-    measure=c("numMicro","numMacro","SSQ", "cRand"),  
+    measure=c("numMicro","numMacro","SSQ", "cRand"),
     n=n, horizon=horizon)
 })
 
@@ -167,7 +167,7 @@ Position <- evaluation[[1]][,"points"]
 cRand <- sapply(evaluation, FUN=function(x) x[,"cRand"])
 cRand
 matplot(Position, cRand, type="l", lwd=2)
-legend("bottomleft", legend=names(evaluation), 
+legend("bottomleft", legend=names(evaluation),
   col=1:6, lty=1:6, bty="n", lwd=2)
 
 
@@ -183,7 +183,7 @@ boxplot(cRand, las=2, cex.axis=.8)
 SSQ <- sapply(evaluation, FUN=function(x) x[,"SSQ"])
 SSQ
 matplot(Position, SSQ, type="l", lwd=2)
-legend("topright", legend=names(evaluation), 
+legend("topright", legend=names(evaluation),
   col=1:6, lty=1:6, bty="n", lwd=2)
 
 
